<?php
/**
 * @version     1.0.0
 * @package     com_docebo
 * @copyright   Copyright (C) 2013. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Docebo Srl. <info@docebo.com> - http://www.docebo.com
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View class for a list of Docebo.
 */
class DoceboViewMycoursess extends JViewLegacy {
	protected $items;
	protected $pagination;
	protected $state;

	/**
	 * Display the view
	 */
	public function display($tpl = NULL) {
		$this->state      = $this->get('State');
		$this->items      = $this->get('Items');
		$this->pagination = $this->get('Pagination');


		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			throw new Exception(implode("\n", $errors));
		}

		$this->addToolbar();

		$input = JFactory::getApplication()->input;
		$view  = $input->getCmd('view', '');
		DoceboHelper::addSubmenu($view);

		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @since    1.6
	 */
	protected function addToolbar() {
		require_once JPATH_COMPONENT . '/helpers/docebo.php';

		$state = $this->get('State');
		$canDo = DoceboHelper::getActions($state->get('filter.category_id'));

		JToolBarHelper::title(JText::_('COM_DOCEBO_TITLE_MYCOURSESS'), 'mycoursess.png');

		//Check if the form exists before showing the add/edit buttons
		$formPath = JPATH_COMPONENT_ADMINISTRATOR . '/views/mycourses';
		if (file_exists($formPath)) {


			if ($canDo->get('core.edit') && isset($this->items[0])) {
				JToolBarHelper::editList('mycourses.edit', 'JTOOLBAR_EDIT');
			} else if ($canDo->get('core.create')) {
				JToolBarHelper::addNew('mycourses.add', 'JTOOLBAR_NEW');
			}

		}

		if ($canDo->get('core.edit.state')) {

			if (isset($this->items[0]->state)) {
				JToolBarHelper::divider();
				JToolBarHelper::custom('mycoursess.publish', 'publish.png', 'publish_f2.png', 'JTOOLBAR_PUBLISH', TRUE);
				JToolBarHelper::custom('mycoursess.unpublish', 'unpublish.png', 'unpublish_f2.png', 'JTOOLBAR_UNPUBLISH', TRUE);
			} else if (isset($this->items[0])) {
				//If this component does not use state then show a direct delete button as we can not trash
				JToolBarHelper::deleteList('', 'mycoursess.delete', 'JTOOLBAR_DELETE');
			}

			if (isset($this->items[0]->state)) {
				JToolBarHelper::divider();
				JToolBarHelper::archiveList('mycoursess.archive', 'JTOOLBAR_ARCHIVE');
			}
			if (isset($this->items[0]->checked_out)) {
				JToolBarHelper::custom('mycoursess.checkin', 'checkin.png', 'checkin_f2.png', 'JTOOLBAR_CHECKIN', TRUE);
			}
		}

		//Show trash and delete for components that uses the state field
		if (isset($this->items[0]->state)) {
			if ($state->get('filter.state') == -2 && $canDo->get('core.delete')) {
				JToolBarHelper::deleteList('', 'mycoursess.delete', 'JTOOLBAR_EMPTY_TRASH');
				JToolBarHelper::divider();
			} else if ($canDo->get('core.edit.state')) {
				JToolBarHelper::trash('mycoursess.trash', 'JTOOLBAR_TRASH');
				JToolBarHelper::divider();
			}
		}

		if ($canDo->get('core.admin')) {
			JToolBarHelper::preferences('com_docebo');
		}
	}

	public function check_sync_scene() {
		$sync_scene = '';
		$db         = JFactory::getDbo();
		$tPrefix    = $db->getPrefix() . 'docebo_general_settings';
		$db->setQuery("SELECT scenario FROM " . $tPrefix . " Limit 1");
		$sync_scene = $db->loadResult();

		return $sync_scene;
	}
}

//------------------------------------------------------------------------------------
// Docebo API Class
global $url, $key, $sso, $secret_key, $getset;

class Api extends JViewLegacy {
	static public $totalmembers;

	static public function getSet() {
		$db      = JFactory::getDbo();
		$tPrefix = $db->getPrefix() . 'docebo_general_settings';
		$db->setQuery("SELECT * FROM " . $tPrefix . " Limit 1");
		$general_settings = $db->loadAssoc();

		return $general_settings;
	}

	static public function getHash($params) {
		$getset     = self::getSet();
		$key        = $getset['api_key'];
		$secret_key = $getset['key'];

		$res           = array('sha1' => '', 'x_auth' => '');
		$res['sha1']   = sha1(implode(',', $params) . ',' . $secret_key);
		$res['x_auth'] = base64_encode($key . ':' . $res['sha1']);

		return $res;
	}

	static private function getDefaultHeader($x_auth) {
		$getset = self::getSet();
		$url    = $getset['cloud_address'];

		// Get the host/domain from the cloud URL
		$url = str_replace('https://', '', $url);
		$url = str_replace('http://', '', $url);
		$url = parse_url('http://' . $url, PHP_URL_HOST);


		return array("Host: " . $url, "Content-Type: multipart/form-data", 'X-Authorization: Docebo ' . $x_auth);
	}

	static public function call($action, $data_params) {
		$getset = self::getSet();
		$url    = trim($getset['cloud_address']);

		$url = str_ireplace('http://', '', $url);
		$url = str_ireplace('https://', '', $url);

		$key        = $getset['api_key'];
		$secret_key = $getset['key'];
		$sso        = $getset['sso'];
		if (!function_exists('curl_version')) {
			return FALSE;
		}
		$curl        = curl_init();
		$hash_info   = self::getHash($data_params);
		$http_header = self::getDefaultHeader($hash_info['x_auth']);
		$opt         = array(
			CURLOPT_URL            => $url . '/api/' . $action,
			CURLOPT_RETURNTRANSFER => 1,
			CURLOPT_HTTPHEADER     => $http_header,
			CURLOPT_POST           => 1,
			CURLOPT_POSTFIELDS     => $data_params,
			CURLOPT_CONNECTTIMEOUT => 5, // Timeout to 5 seconds
			CURLOPT_SSL_VERIFYPEER => FALSE,
			CURLOPT_SSL_VERIFYHOST => FALSE,
		);
		curl_setopt_array($curl, $opt);
		// $output contains the output string
		$output = curl_exec($curl);
		// it closes the session
		curl_close($curl);

		return $output;
	}

	static public function sso($user) {
		$getset = self::getSet();
		$url    = trim($getset['cloud_address']);
		if (!$url)
			return FALSE;

		if (stripos($url, 'http://') === FALSE && stripos($url, 'https://') === FALSE)
			$url = 'http://' . $url;

			$sso = $getset['sso'];
			
			// Get an instance of the cache object
			$cache = JFactory::getCache();
			
			// Get the current user's ID so we can get his Docebo username through API
			$user = JFactory::getUser()->get('id');
			
			$username = $cache->call(array('Api', 'userToDoceboUser'), $user);
			
			$time = time();
			$token = md5(strtolower($username).','.$time.','.$sso);
			return $url . '/doceboLms/index.php?auth_regen=1&modname=login&op=confirm&login_user=' . urlencode(strtolower($username)) . '&time=' . $time . '&token=' . $token;
		}
		
		static public function userToDoceboUser($user){
			
			// Get the Docebo username that is associated
			// with the currently logged in Joomla user
			// (through API)
			$params = array(
				'ext_user' => $user,
				'ext_user_type' => 'wordpress',
			);
			$apiResponse = self::call('user/profile/', $params);
			$docebo_user_info = json_decode($apiResponse);

			if($docebo_user_info && isset($docebo_user_info->userid))
				return $docebo_user_info->userid;

			$user = JFactory::getUser($user);
			if($user){
				return $user->username;
			}
						
			return FALSE;
		}
	}